unit TextEditorU;

interface

uses
  SysUtils, Types, Classes, Variants, QGraphics, QControls, QForms, QDialogs,
  QImgList, QMenus, QTypes, QStdCtrls;

type
  TForm1 = class(TForm)
    memText: TMemo;
    MainMenu1: TMainMenu;
    dlgOpen: TOpenDialog;
    dlgSave: TSaveDialog;
    File1: TMenuItem;
    mniNew: TMenuItem;
    mniOpen: TMenuItem;
    mniSave: TMenuItem;
    N1: TMenuItem;
    mniExit: TMenuItem;
    Edit1: TMenuItem;
    mniCut: TMenuItem;
    mniCopy: TMenuItem;
    mniPaste: TMenuItem;
    Help1: TMenuItem;
    mniAbout: TMenuItem;
    procedure FormCreate(Sender: TObject);
    procedure FormCloseQuery(Sender: TObject; var CanClose: Boolean);
    procedure mniNewClick(Sender: TObject);
    procedure mniOpenClick(Sender: TObject);
    procedure mniSaveClick(Sender: TObject);
    procedure mniExitClick(Sender: TObject);
    procedure mniCutClick(Sender: TObject);
    procedure mniCopyClick(Sender: TObject);
    procedure mniPasteClick(Sender: TObject);
    procedure mniAboutClick(Sender: TObject);
    procedure memTextChange(Sender: TObject);
  private
    Modified: Boolean;
    FFileName: String;
    procedure SetFileName(FileName: String);
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

{$R *.xfm}

procedure TForm1.SetFileName(FileName: String);
begin
  FFileName := FileName;
  if FFileName = '' then
    Caption := '<new file>'
  else
    Caption := FFileName
end;

procedure TForm1.FormCreate(Sender: TObject);
begin
  SetFileName(FFileName);
end;

procedure TForm1.FormCloseQuery(Sender: TObject; var CanClose: Boolean);
begin
  mniNewClick(mniNew);
  if Modified then
    CanClose := False
  //CanClose := not Modified
end;

procedure TForm1.mniNewClick(Sender: TObject);
begin
  if Modified then
    case MessageDlg('Save changes?', mtConfirmation,
           [mbYes, mbNo, mbCancel], 0) of
      mrYes: mniSaveClick(mniSave);
      mrNo: Modified := False;
      mrCancel: Exit;
    end;
  if not Modified then
  begin
    SetFileName('');
    memText.Clear;
    Modified := False
  end
end;

procedure TForm1.mniOpenClick(Sender: TObject);
begin
  if dlgOpen.Execute then
  begin
    memText.Lines.LoadFromFile(dlgOpen.FileName);
    Modified := False;
    SetFileName(dlgOpen.FileName)
  end
end;

procedure TForm1.mniSaveClick(Sender: TObject);
begin
  if FFileName = '' then
    if dlgSave.Execute then
      SetFileName(dlgSave.FileName);
  if FFileName <> '' then
  begin
    memText.Lines.SaveToFile(FFileName);
    Modified := False;
  end
end;

procedure TForm1.mniExitClick(Sender: TObject);
begin
  Close
end;

procedure TForm1.mniCutClick(Sender: TObject);
begin
  memText.CutToClipboard
end;

procedure TForm1.mniCopyClick(Sender: TObject);
begin
  memText.CopyToClipboard
end;

procedure TForm1.mniPasteClick(Sender: TObject);
begin
  memText.PasteFromClipboard
end;

procedure TForm1.mniAboutClick(Sender: TObject);
begin
  ShowMessage('Text Editor application')
end;

procedure TForm1.memTextChange(Sender: TObject);
begin
  Modified := True
end;

end.
